@@ -1,6 +1,6 @@
 package Silki::Controller::Base;
 BEGIN {
-  $Silki::Controller::Base::VERSION = '0.26';
+  $Silki::Controller::Base::VERSION = '0.27';
 }
 
 use strict;
@@ -29,7 +29,7 @@ sub begin : Private {
 
     return unless $c->request()->looks_like_browser();
 
-    my $config = Silki::Config->new();
+    my $config = Silki::Config->instance();
 
     unless ( $config->is_production() || $config->is_profiling() ) {
         $_->new()->create_single_file()
@@ -207,7 +207,7 @@ Silki::Controller::Base - Controller base class
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 AUTHOR
 
