@@ -1,6 +1,6 @@
 package Silki::Controller::Page;
 BEGIN {
-  $Silki::Controller::Page::VERSION = '0.26';
+  $Silki::Controller::Page::VERSION = '0.27';
 }
 
 use strict;
@@ -37,7 +37,7 @@ sub _set_page : Chained('/wiki/_set_wiki') : PathPart('page') : CaptureArgs(1) {
     # the original form.
     my $page_path = ( split /\//, $c->request()->path_info() )[3];
 
-    if ( Silki::Config->new()->mod_rewrite_hack() ) {
+    if ( Silki::Config->instance()->mod_rewrite_hack() ) {
         $page_path =~ s/_/ /g;
         $page_path = Silki::Schema::Page->TitleToURIPath($page_path);
     }
@@ -392,7 +392,7 @@ sub _handle_upload {
         );
     }
 
-    if ( $upload->size() > Silki::Config->new()->max_upload_size() ) {
+    if ( $upload->size() > Silki::Config->instance()->max_upload_size() ) {
         $c->redirect_with_error(
             error => loc('The file you uploaded was too large.'),
             uri   => $on_error,
@@ -543,7 +543,7 @@ Silki::Controller::Page - Controller class for pages
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 AUTHOR
 
